@@ -158,7 +158,6 @@ from __future__ import annotations
 import abc
 import copy
 import inspect
-import logging
 import os
 import sys
 
@@ -170,7 +169,6 @@ from collections import OrderedDict
 from typing import (
     Dict,
     Iterable,
-    BinaryIO,
     Sequence,
     Set,
     Type,
@@ -201,7 +199,11 @@ from refinery.lib.argparser import ArgumentParserWithKeywordHooks, ArgparseError
 from refinery.lib.tools import documentation, isstream, lookahead, autoinvoke, one, skipfirst, isbuffer
 from refinery.lib.frame import Framed, Chunk
 from refinery.lib.structures import MemoryFile
-from refinery.lib.environment import LogLevel, environment
+from refinery.lib.environment import LogLevel, Logger, environment, logger
+from refinery.lib.types import ByteStr
+
+
+ByteIO = MemoryFile[ByteStr]
 
 
 class RefineryPartialResult(ValueError):
@@ -914,30 +916,14 @@ class Executable(ABCMeta):
     def name(cls) -> str:
         return cls.__name__.strip('_').replace('_', '-')
 
-
-    logging.addLevelName(logging.CRITICAL, 'failure') # noqa
-    logging.addLevelName(logging.ERROR,    'failure') # noqa
-    logging.addLevelName(logging.WARNING,  'warning') # noqa
-    logging.addLevelName(logging.INFO,     'comment') # noqa
-    logging.addLevelName(logging.DEBUG,    'verbose') # noqa
-
     @property
-    def logger(cls) -> logging.Logger:
+    def logger(cls) -> Logger:
         try:
             return cls._logger
         except AttributeError:
             pass
-        cls._logger = logger = logging.getLogger(cls.name)
-        if not logger.hasHandlers():
-            stream = logging.StreamHandler()
-            stream.setFormatter(logging.Formatter(
-                '({asctime}) {levelname} in {name}: {message}',
-                style='{',
-                datefmt='%H:%M:%S'
-            ))
-            logger.addHandler(stream)
-        logger.propagate = False
-        return logger
+        cls._logger = _logger = logger(cls.name)
+        return _logger
 
 
 class DelayedArgumentProxy:
@@ -1154,7 +1140,7 @@ class Unit(UnitBase, abstract=True):
 
     @property
     def logger(self):
-        logger: logging.Logger = self.__class__.logger
+        logger: Logger = self.__class__.logger
         return logger
 
     @property
@@ -1348,6 +1334,12 @@ class Unit(UnitBase, abstract=True):
     def __pos__(self):
         return self
 
+    def __del__(self):
+        try:
+            self.nozzle.source.close()
+        except Exception:
+            pass
+
     def __neg__(self):
         pipeline = []
         cursor = self
@@ -1363,7 +1355,7 @@ class Unit(UnitBase, abstract=True):
             reversed = reversed | pipeline.pop()
         return reversed
 
-    def __ror__(self, stream: Union[str, BinaryIO, ByteString]):
+    def __ror__(self, stream: Union[str, ByteIO, ByteString]):
         if stream is None:
             return self
         if not isstream(stream):
@@ -1417,7 +1409,7 @@ class Unit(UnitBase, abstract=True):
         ...
 
     @overload
-    def __or__(self, stream: BinaryIO) -> BinaryIO:
+    def __or__(self, stream: ByteIO) -> ByteIO:
         ...
 
     def __or__(self, stream):
@@ -1481,6 +1473,8 @@ class Unit(UnitBase, abstract=True):
                     out = out.decode(self.codec)
                 return stream(out)
 
+        stream: ByteIO
+
         if not stream.writable():
             raise ValueError('target stream is not writable')
 
@@ -1572,6 +1566,7 @@ class Unit(UnitBase, abstract=True):
 
     def __call__(self, data: Optional[Union[ByteString, Chunk]] = None) -> bytes:
         with MemoryFile(data) if data else open(os.devnull, 'rb') as stdin:
+            stdin: ByteIO
             with MemoryFile() as stdout:
                 return (stdin | self | stdout).getvalue()
 
@@ -1828,7 +1823,7 @@ class Unit(UnitBase, abstract=True):
             from time import process_time
             argv.remove(cls._SECRET_DEBUG_TIMING_FLAG)
             clock = process_time()
-            cls.logger.setLevel(logging.INFO)
+            cls.logger.setLevel(LogLevel.INFO)
             cls.logger.info('starting clock: {:.4f}'.format(clock))
 
         if cls._SECRET_YAPPI_TIMING_FLAG in argv:
